@@ -48,7 +48,7 @@ evaluation<-function(y,dilution,inhib,outdir,file,graphics){
     }
     else cv[cp]<-NA
 
-    if(2*nval>=length(ic50[[cp]]) && var(ic50[[cp]],na.rm=TRUE)!=0){
+    if(2*nval>=length(ic50[[cp]]) && var(ic50[[cp]],na.rm=TRUE)!=0 && sum(!is.na(ic50[[cp]]))>=2){
       cl[cp]<-ic50mean[cp]-qt(p=.975,df=nval)*sqrt(var(ic50[[cp]],na.rm=TRUE)/nval) #Confidence interval
       cu[cp]<-ic50mean[cp]+qt(p=.975,df=nval)*sqrt(var(ic50[[cp]],na.rm=TRUE)/nval)
     }
